@@ -23,7 +23,7 @@ class TQPoint;
 
 class KBiffStatusItem : TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
 	KBiffStatusItem(const TQString& mailbox, const int num_new);
 	KBiffStatusItem(const TQString& mailbox, const int num_new,const int num_cur);
@@ -44,7 +44,7 @@ typedef TQPtrListIterator<KBiffStatusItem> KBiffStatusListIterator;
 
 class KBiffStatus : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KBiffStatus(TQWidget *parent, const TQString& profile, const KBiffStatusList& list);
 	virtual ~KBiffStatus();
